==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/space/messages/fr/base.php <==
<?php
return array (
  '<b>This space is still empty!</b>' => '<b>Cet espace est encore vide !</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Cet espace est encore vide !</b><br>Commencez par publier quelque chose ici…',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Vous n\'êtes pas membre de cet espace et il n\'y a aucun contenu public à afficher pour l\'instant.</b>',
  '<strong>About</strong> the Space' => '<strong>À propos</strong> de cet espace',
  '<strong>About</strong> your membership' => '<strong>À propos</strong> de votre adhésion',
  '<strong>Confirm</strong> image deletion' => '<strong>Confirmer</strong> la suppression de l\'image',
  '<strong>Invite</strong> members' => '<strong>Inviter</strong> des membres',
  '<strong>New</strong> member request' => '<strong>Nouvelle</strong> demande d\'adhésion',
  '<strong>New</strong> spaces' => '<strong>Nouveaux</strong> espaces',
  '<strong>Request</strong> Membership' => '<strong>Demande</strong> d’adhésion à cet espace',
  '<strong>Space</strong> followers' => '<strong>Abonnés</strong> à cet espace',
  '<strong>Space</strong> members' => '<strong>Membres</strong> de cet espace',
  '<strong>Space</strong> menu' => 'Menu <strong>espace</strong>',
  '<strong>Space</strong> tags' => 'Étiquettes <strong>l\'espace</strong>',
  '<strong>Spaces</strong>' => '<strong>Espaces</strong>',
  'About' => 'À propos',
  'Accept' => 'Accepter',
  'Accept Invite' => 'Accepter l\'invitation',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Merci de vous présenter en quelques mots afin de devenir membre de cet espace.',
  'Add users without invitation' => 'Ajouter des utilisateurs sans les inviter',
  'Admin' => 'Administrateur',
  'Administrator:' => 'Administrateur :',
  'Administrators' => 'Administrateurs',
  'Any' => 'Aucun',
  'Archived' => 'Archivé',
  'As owner you cannot revoke your membership!' => 'En tant que propriétaire, vous ne pouvez pas révoquer votre participation.',
  'Blocked users' => 'Utilisateurs bloqués',
  'By Name' => 'Par Nom',
  'Cancel' => 'Annuler',
  'Change visibility' => 'Changer la visibilité',
  'Close' => 'Fermer',
  'Color' => 'Couleur',
  'Could not request membership!' => 'Demande d\'adhésion impossible.',
  'Create new link' => 'Créer un nouveau lien',
  'Created At' => 'Créé le',
  'Created By' => 'Créé par',
  'Decline' => 'Refuser',
  'Decline Invite' => 'Refuser l\'invitation',
  'Default' => 'Par défaut',
  'Default content visibility' => 'Visibilité par défaut des contenus',
  'Delete' => 'Supprimer',
  'Description' => 'Description',
  'Do you really want to delete your profile image?' => 'Souhaitez-vous vraiment supprimer l\'image de votre profil ?',
  'Do you really want to delete your title image?' => 'Souhaitez-vous vraiment supprimer cette image ?',
  'Done' => 'Terminé',
  'Email addresses' => 'Adresses e-mail',
  'Everyone can enter' => 'Tout le monde peut entrer',
  'Find Spaces by their description or by their tags' => 'Trouver des Espaces par leur description ou leurs mots clés',
  'Follow' => 'Suivre',
  'Followers' => 'Abonnés',
  'Following' => 'Abonnements',
  'Guests' => 'Invités',
  'Hide About Page' => 'Masquer la page "A propos"',
  'Hide Activity Sidebar Widget' => 'Masquer le widget d’activités dans la barre latérale',
  'Hide Followers' => 'Masquer les abonnés',
  'Hide Members' => 'Masquer les membres',
  'Homepage' => 'Page d\'accueil',
  'Homepage (Non-members)' => 'Page d\'accueil (non membres)',
  'I want to become a member because...' => 'Je souhaite devenir membre car…',
  'Invite' => 'Inviter',
  'Invite and request' => 'Sur invitation et demande',
  'Invite by email' => 'Inviter par e-mail',
  'Invite by link' => 'Inviter par lien',
  'Invite link' => 'Lien d\'invitation',
  'Invites' => 'Invitations',
  'Join' => 'Rejoindre',
  'Join Policy' => 'Conditions d\'adhésion',
  'Last Visit' => 'Dernière visite',
  'Login' => 'Identification',
  'Max. 100 characters.' => '100 caractères max.',
  'Member' => 'Membre',
  'Member since' => 'Membre depuis',
  'Members' => 'Membres',
  'Moderator' => 'Modérateur',
  'Moderator:' => 'Modérateur :',
  'Moderators' => 'Modérateurs',
  'My Space List' => 'Ma liste d\'espaces',
  'My space summary' => 'Résumé de mes espaces',
  'Name' => 'Nom',
  'Name / Sort order' => 'Nom / ordre de tri',
  'Neither..nor' => 'Ni l\'un·e..ni l\'autre',
  'New user by e-mail (comma separated)' => 'e-mail des nouveaux utilisateurs (séparés par une virgule)',
  'New user?' => 'Nouvel utilisateur ?',
  'Newest first' => 'Plus récents d\'abord',
  'No results found!' => 'Aucun résultat !',
  'No spaces found.' => 'Aucun espace trouvé.',
  'Oldest first' => 'Plus anciens d\'abord',
  'Only by invite' => 'Sur invitation uniquement',
  'Originator User ID' => 'ID de l\'utilisateur d\'origine',
  'Owner' => 'Propriétaire',
  'Owner:' => 'Propriétaire :',
  'Pending' => 'En attente',
  'Pick users' => 'Sélectionner les utilisateurs',
  'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Veuillez noter que tous les liens que vous avez créés précédemment ne seront plus valides dès que vous en créerez un nouveau. Voulez vous procéder malgré tout ?',
  'Posts' => 'Publications',
  'Private' => 'Privé',
  'Private (Invisible)' => 'Privé (invisible)',
  'Public' => 'Public',
  'Public (Members & Guests)' => 'Public (membres et visiteurs)',
  'Public (Members only)' => 'Public (membres uniquement)',
  'Public (Registered users only)' => 'Public (utilisateurs connectés uniquement)',
  'Request Message' => 'Contenu de la demande',
  'Role' => 'Rôle',
  'Search...' => 'Rechercher...',
  'See all' => 'Voir tous',
  'Select all registered users' => 'Sélectionner tous les utilisateurs qui ont un compte',
  'Send' => 'Envoyer',
  'Send the link via email' => 'Envoyer le lien par email',
  'Settings' => 'Réglages',
  'Settings could not be saved!' => 'Les paramètres ne peuvent être enregistrés.',
  'Show all' => 'Afficher tout',
  'Show as List' => 'Afficher sous forme de liste',
  'Shown on About Page.' => 'Affiché sur la page "À propos"',
  'Sorry, you are not allowed to leave this space!' => 'Désolé, vous n\'êtes pas autorisé à quitter cet espace.',
  'Sorting' => 'Trier',
  'Space' => 'Espace',
  'Space Visibility' => 'Visibilité de cet espace',
  'Space directory' => 'Liste des espaces',
  'Space is invisible!' => 'Espace invisible',
  'Spaces' => 'Espaces',
  'Status' => 'Statut',
  'Stream' => 'Fil d\'actualités',
  'Tags' => 'Mots-clés',
  'The default homepage for members of this Space' => 'La page d\'accueil par défaut pour les membres de cet espace',
  'The default homepage for non-members and guests visiting this Space' => 'La page d\'accueil par défaut pour les non-membres et les invités visitant cet espace',
  'The secure link has been copied in your clipboard!' => 'Le lien sécurisé a été copié dans votre presse-papiers !',
  'There is no pending invite!' => 'Aucune invitation en attente.',
  'This action is only available for workspace members!' => 'Cette action n\'est disponible que pour les membres de cet espace.',
  'This user is already a member of this space.' => 'Cet utilisateur est déjà membre de cet espace.',
  'This user is not a member of this space.' => 'Cet utilisateur n\'est pas membre de cet espace.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Pour inviter des membres dans cet espace, saisissez leurs noms ci-dessous et cochez les.',
  'Try other keywords or remove filters.' => 'Essayez d\'autres mots-clés ou supprimez les filtres.',
  'Updated At' => 'Mis à jour le',
  'Updated By' => 'Mis à jour par',
  'Updated by' => 'Mis à jour par',
  'User \'{username}\' is already a member of this space!' => 'L\'utilisateur "{username}" est déjà membre de cet espace.',
  'User invitations have been added to the queue' => 'Les invitations des utilisateurs ont été ajoutées à la file d\'attente',
  'User memberships have been added to the queue' => 'Les adhésions des utilisateurs ont été ajoutées à la file d\'attente',
  'User not found!' => 'Utilisateur introuvable.',
  'Users' => 'Utilisateurs',
  'Users has been invited.' => 'Les utilisateurs ont été invités.',
  'Visibility' => 'Visibilité',
  'Visible for all (members and guests)' => 'Visible par tous (utilisateurs connectés et visiteurs)',
  'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Attention : si vous passez le réglage de visibilité d’un Espace de public à privé, tous les contenus de cet Espace (publications, commentaires, pièces jointes, etc.) deviennent également privés. En conséquence, les non-membres ne pourront plus voir, accéder ni interagir avec ces contenus.',
  'Would you like to end your membership in Space {spaceName}?' => 'Voulez-vous annuler votre abonnement à l\'espace {spaceName}?',
  'Would you like to unfollow Space {spaceName}?' => 'Voulez-vous arrêter de suivre l\'espace {spaceName}?',
  'Would you like to unfollow {userName}?' => 'Voulez-vous arrêter de suivre {userName}?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Voulez-vous annuler votre demande d’adhésion à l\'espace {spaceName}?',
  'You are not allowed to join this space!' => 'Vous n\'êtes pas autorisé à rejoindre cet espace.',
  'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Vous pouvez également inviter des utilisateurs externes par e-mail, qui ne sont pas encore enregistrés. Ajoutez simplement leurs adresses e-mail séparées par des virgules.',
  'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Vous pouvez inviter des utilisateurs externes qui ne sont actuellement pas enregistrés via un lien. Vous n\'aurez plus qu\'à partager ce lien sécurisé avec eux.',
  'You cannot create private visible spaces!' => 'Vous ne pouvez pas créer un espace privé visible.',
  'You cannot create public visible spaces!' => 'Vous ne pouvez pas créer un espace public visible.',
  'You need to login to view contents of this space!' => 'Vous devez être connecté pour visualiser le contenu de cet espace.',
  'Your Message' => 'Message',
  'Your request was successfully submitted to the space administrators.' => 'Votre demande a été transmise à l\'administrateur de cet espace.',
  '{count} members' => '{count} membres',
  '{email} is not valid!' => '{email} n\'est pas valide.',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/space/messages/fr/base.php <==
<?php
return array (
  '<b>This space is still empty!</b>' => '<b>Cet espace est encore vide !</b>',
  '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>Cet espace est encore vide !</b><br>Commencez par publier quelque chose ici…',
  '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>Vous n\'êtes pas membre de cet espace et il n\'y a aucun contenu public à afficher pour l\'instant.</b>',
  '<strong>About</strong> the Space' => '<strong>À propos</strong> de cet espace',
  '<strong>About</strong> your membership' => '<strong>À propos</strong> de votre adhésion',
  '<strong>Confirm</strong> image deletion' => '<strong>Confirmer</strong> la suppression de l\'image',
  '<strong>Invite</strong> members' => '<strong>Inviter</strong> des membres',
  '<strong>Leave</strong> Space' => '<strong>Quitter</strong> l’espace',
  '<strong>New</strong> member request' => '<strong>Nouvelle</strong> demande d\'adhésion',
  '<strong>New</strong> spaces' => '<strong>Nouveaux</strong> espaces',
  '<strong>Request</strong> Membership' => '<strong>Demande</strong> d’adhésion à cet espace',
  '<strong>Space</strong> followers' => '<strong>Abonnés</strong> à cet espace',
  '<strong>Space</strong> members' => '<strong>Membres</strong> de cet espace',
  '<strong>Space</strong> menu' => 'Menu <strong>espace</strong>',
  '<strong>Space</strong> tags' => 'Étiquettes <strong>l\'espace</strong>',
  '<strong>Spaces</strong>' => '<strong>Espaces</strong>',
  'About' => 'À propos',
  'Accept' => 'Accepter',
  'Accept Invite' => 'Accepter l\'invitation',
  'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Merci de vous présenter en quelques mots afin de devenir membre de cet espace.',
  'Add users without invitation' => 'Ajouter des utilisateurs sans les inviter',
  'Admin' => 'Administrateur',
  'Administrator:' => 'Administrateur :',
  'Administrators' => 'Administrateurs',
  'Advanced Spaces Search' => 'Recherche avancée dans les espaces',
  'Any' => 'Aucun',
  'Archived' => 'Archivé',
  'As owner you cannot revoke your membership!' => 'En tant que propriétaire, vous ne pouvez pas révoquer votre participation.',
  'Blocked users' => 'Utilisateurs bloqués',
  'By Name' => 'Par Nom',
  'Cancel' => 'Annuler',
  'Change visibility' => 'Changer la visibilité',
  'Close' => 'Fermer',
  'Color' => 'Couleur',
  'Could not request membership!' => 'Demande d\'adhésion impossible.',
  'Create new link' => 'Créer un nouveau lien',
  'Created At' => 'Créé le',
  'Created By' => 'Créé par',
  'Decline' => 'Refuser',
  'Decline Invite' => 'Refuser l\'invitation',
  'Default' => 'Par défaut',
  'Default content visibility' => 'Visibilité par défaut des contenus',
  'Delete' => 'Supprimer',
  'Description' => 'Description',
  'Do you really want to delete your profile image?' => 'Souhaitez-vous vraiment supprimer l\'image de votre profil ?',
  'Do you really want to delete your title image?' => 'Souhaitez-vous vraiment supprimer cette image ?',
  'Done' => 'Terminé',
  'Email addresses' => 'Adresses e-mail',
  'Everyone can enter' => 'Tout le monde peut entrer',
  'Find Spaces by their description or by their tags' => 'Trouver des Espaces par leur description ou leurs mots clés',
  'Follow' => 'Suivre',
  'Followers' => 'Abonnés',
  'Following' => 'Abonnements',
  'Guests' => 'Invités',
  'Hide About Page' => 'Masquer la page "A propos"',
  'Hide Activity Sidebar Widget' => 'Masquer le widget d’activités dans la barre latérale',
  'Hide Followers' => 'Masquer les abonnés',
  'Hide Members' => 'Masquer les membres',
  'Homepage' => 'Page d\'accueil',
  'Homepage (Non-members)' => 'Page d\'accueil (non membres)',
  'I want to become a member because...' => 'Je souhaite devenir membre car…',
  'Incorrect name, try again.' => 'Nom incorrect, réessayez.',
  'Invite' => 'Inviter',
  'Invite and request' => 'Sur invitation et demande',
  'Invite by email' => 'Inviter par e-mail',
  'Invite by link' => 'Inviter par lien',
  'Invite link' => 'Lien d\'invitation',
  'Invites' => 'Invitations',
  'Join' => 'Rejoindre',
  'Join Policy' => 'Conditions d\'adhésion',
  'Last Visit' => 'Dernière visite',
  'Leave' => 'Quitter',
  'Login' => 'Identification',
  'Max. 100 characters.' => '100 caractères max.',
  'Member' => 'Membre',
  'Member since' => 'Membre depuis',
  'Members' => 'Membres',
  'Moderator' => 'Modérateur',
  'Moderator:' => 'Modérateur :',
  'Moderators' => 'Modérateurs',
  'My Space List' => 'Ma liste d\'espaces',
  'My space summary' => 'Résumé de mes espaces',
  'Name' => 'Nom',
  'Name / Sort order' => 'Nom / ordre de tri',
  'Neither..nor' => 'Ni l\'un·e..ni l\'autre',
  'New user by e-mail (comma separated)' => 'e-mail des nouveaux utilisateurs (séparés par une virgule)',
  'New user?' => 'Nouvel utilisateur ?',
  'Newest first' => 'Plus récents d\'abord',
  'No results found!' => 'Aucun résultat !',
  'No spaces found.' => 'Aucun espace trouvé.',
  'Oldest first' => 'Plus anciens d\'abord',
  'Only by invite' => 'Sur invitation uniquement',
  'Originator User ID' => 'ID de l\'utilisateur d\'origine',
  'Owner' => 'Propriétaire',
  'Owner:' => 'Propriétaire :',
  'Pending' => 'En attente',
  'Pick users' => 'Sélectionner les utilisateurs',
  'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Veuillez noter que tous les liens que vous avez créés précédemment ne seront plus valides dès que vous en créerez un nouveau. Voulez vous procéder malgré tout ?',
  'Posts' => 'Publications',
  'Private' => 'Privé',
  'Private (Invisible)' => 'Privé (invisible)',
  'Public' => 'Public',
  'Public (Members & Guests)' => 'Public (membres et visiteurs)',
  'Public (Members only)' => 'Public (membres uniquement)',
  'Public (Registered users only)' => 'Public (utilisateurs connectés uniquement)',
  'Request Message' => 'Contenu de la demande',
  'Role' => 'Rôle',
  'Search...' => 'Rechercher...',
  'See all' => 'Voir tous',
  'Select all registered users' => 'Sélectionner tous les utilisateurs qui ont un compte',
  'Send' => 'Envoyer',
  'Send the link via email' => 'Envoyer le lien par email',
  'Settings' => 'Réglages',
  'Settings could not be saved!' => 'Les paramètres ne peuvent être enregistrés.',
  'Show all' => 'Afficher tout',
  'Show as List' => 'Afficher sous forme de liste',
  'Shown on About Page.' => 'Affiché sur la page "À propos"',
  'Sorry, you are not allowed to leave this space!' => 'Désolé, vous n\'êtes pas autorisé à quitter cet espace.',
  'Sorting' => 'Trier',
  'Space' => 'Espace',
  'Space Name' => 'Nom de l’espace',
  'Space Visibility' => 'Visibilité de l’espace',
  'Space directory' => 'Liste des espaces',
  'Space is invisible!' => 'Espace invisible',
  'Spaces' => 'Espaces',
  'Status' => 'Statut',
  'Stream' => 'Fil d\'actualités',
  'Tags' => 'Mots-clés',
  'The default homepage for members of this Space' => 'La page d\'accueil par défaut pour les membres de cet espace',
  'The default homepage for non-members and guests visiting this Space' => 'La page d\'accueil par défaut pour les non-membres et les invités visitant cet espace',
  'The secure link has been copied in your clipboard!' => 'Le lien sécurisé a été copié dans votre presse-papiers !',
  'There is no pending invite!' => 'Aucune invitation en attente.',
  'This action is only available for workspace members!' => 'Cette action n\'est disponible que pour les membres de cet espace.',
  'This user is already a member of this space.' => 'Cet utilisateur est déjà membre de cet espace.',
  'This user is not a member of this space.' => 'Cet utilisateur n\'est pas membre de cet espace.',
  'To invite users to this space, please type their names below to find and pick them.' => 'Pour inviter des membres dans cet espace, saisissez leurs noms ci-dessous et cochez les.',
  'Try other keywords or remove filters.' => 'Essayez d\'autres mots-clés ou supprimez les filtres.',
  'Updated At' => 'Mis à jour le',
  'Updated By' => 'Mis à jour par',
  'Updated by' => 'Mis à jour par',
  'User \'{username}\' is already a member of this space!' => 'L\'utilisateur "{username}" est déjà membre de cet espace.',
  'User invitations have been added to the queue' => 'Les invitations des utilisateurs ont été ajoutées à la file d\'attente',
  'User memberships have been added to the queue' => 'Les adhésions des utilisateurs ont été ajoutées à la file d\'attente',
  'User not found!' => 'Utilisateur introuvable.',
  'Users' => 'Utilisateurs',
  'Users has been invited.' => 'Les utilisateurs ont été invités.',
  'Visibility' => 'Visibilité',
  'Visible for all (members and guests)' => 'Visible par tous (utilisateurs connectés et visiteurs)',
  'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Attention : si vous passez le réglage de visibilité d’un Espace de public à privé, tous les contenus de cet Espace (publications, commentaires, pièces jointes, etc.) deviennent également privés. En conséquence, les non-membres ne pourront plus voir, accéder ni interagir avec ces contenus.',
  'Would you like to end your membership in Space {spaceName}?' => 'Voulez-vous annuler votre abonnement à l\'espace {spaceName}?',
  'Would you like to unfollow Space {spaceName}?' => 'Voulez-vous arrêter de suivre l\'espace {spaceName}?',
  'Would you like to unfollow {userName}?' => 'Voulez-vous arrêter de suivre {userName}?',
  'Would you like to withdraw your request to join Space {spaceName}?' => 'Voulez-vous annuler votre demande d’adhésion à l\'espace {spaceName}?',
  'You are not allowed to join this space!' => 'Vous n\'êtes pas autorisé à rejoindre cet espace.',
  'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Vous pouvez également inviter des utilisateurs externes par e-mail, qui ne sont pas encore enregistrés. Ajoutez simplement leurs adresses e-mail séparées par des virgules.',
  'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Vous pouvez inviter des utilisateurs externes qui ne sont actuellement pas enregistrés via un lien. Vous n\'aurez plus qu\'à partager ce lien sécurisé avec eux.',
  'You cannot create private visible spaces!' => 'Vous ne pouvez pas créer un espace privé visible.',
  'You cannot create public visible spaces!' => 'Vous ne pouvez pas créer un espace public visible.',
  'You need to login to view contents of this space!' => 'Vous devez être connecté pour visualiser le contenu de cet espace.',
  'Your Message' => 'Message',
  'Your request was successfully submitted to the space administrators.' => 'Votre demande a été transmise à l\'administrateur de cet espace.',
  '{count} members' => '{count} membres',
  '{email} is not valid!' => '{email} n\'est pas valide.',
);
